==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtsortHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "R[h̕׊"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "ږXg"
#define FLDC "R[h׊ƂȂ鍀ږXg"
#define FLDF "l,t"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "ږXgŎw肵ڂɂāAR[h׊B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtsort -k ڋq,t -i dat.xt -o rsl.xt\n\
xtsort -k ڋq,z%n -i dat.xt -o rsl.xt\n\
xtsort -k ڋq,z%nr -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/ja-sjis/xtsortHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "R[h̕׊"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "ږXg"
#define FLDC "R[h׊ƂȂ鍀ږXg"
#define FLDF "l,t"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "ږXgŎw肵ڂɂāAR[h׊B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtsort -k ڋq,t -i dat.xt -o rsl.xt\n\
xtsort -k ڋq,z%n -i dat.xt -o rsl.xt\n\
xtsort -k ڋq,z%nr -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
